@@ -404,6 +404,9 @@ INVALIDPARAMETERVALUE_EXTERNALIPQUOTALIMITED = 'InvalidParameterValue.ExternalIp
 # 非GPU实例不允许转为GPU实例。
 INVALIDPARAMETERVALUE_GPUINSTANCEFAMILY = 'InvalidParameterValue.GPUInstanceFamily'
 
+# 非CDC场景不支持HpcClusterBusinessId。
+INVALIDPARAMETERVALUE_HPCCLUSTERBUSINESSIDNOTSUPPORTED = 'InvalidParameterValue.HpcClusterBusinessIdNotSupported'
+
 # 您的高性能计算集群已经绑定其他可用区，不能购买当前可用区机器。
 INVALIDPARAMETERVALUE_HPCCLUSTERIDZONEIDNOTMATCH = 'InvalidParameterValue.HpcClusterIdZoneIdNotMatch'
 
@@ -488,6 +491,9 @@ INVALIDPARAMETERVALUE_INVALIDIMAGESTATE = 'InvalidParameterValue.InvalidImageSta
 # 该实例配置来自免费升配活动，暂不支持3个月内进行降配。
 INVALIDPARAMETERVALUE_INVALIDINSTANCESOURCE = 'InvalidParameterValue.InvalidInstanceSource'
 
+# 该机型不支持周期合约
+INVALIDPARAMETERVALUE_INVALIDINSTANCETYPEPERIODICCONTRACT = 'InvalidParameterValue.InvalidInstanceTypePeriodicContract'
+
 # 指定机型不支持包销付费模式。
 INVALIDPARAMETERVALUE_INVALIDINSTANCETYPEUNDERWRITE = 'InvalidParameterValue.InvalidInstanceTypeUnderwrite'
 
@@ -572,6 +578,9 @@ INVALIDPARAMETERVALUE_LIMITEXCEEDED = 'InvalidParameterValue.LimitExceeded'
 # 本地盘的限制范围。
 INVALIDPARAMETERVALUE_LOCALDISKSIZERANGE = 'InvalidParameterValue.LocalDiskSizeRange'
 
+# 专属可用区本地COS集群缺少endpoint配置
+INVALIDPARAMETERVALUE_MISSINGLOCATIONCOSENDPOINT = 'InvalidParameterValue.MissingLocationCosEndpoint'
+
 # 参数值必须为开启DHCP的VPC
 INVALIDPARAMETERVALUE_MUSTDHCPENABLEDVPC = 'InvalidParameterValue.MustDhcpEnabledVpc'
 
